@@ -1,18 +1,21 @@
 /* arp.h - ARP state machine */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #ifndef ARP_H
 #define ARP_H
 
+#include <stdint.h>
 #include <linux/atmarp.h>
 
 #include "table.h"
 
 
+void discard_vccs(ENTRY *entry);
 void discard_entry(ENTRY *entry);
-void need_ip(int itf_num,unsigned long ip);
+void vcc_detach(ENTRY *entry);
+void need_ip(int itf_num,uint32_t ip);
 void incoming_arp(VCC *vcc,struct atmarphdr *hdr,int len);
 int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req);
 void vcc_connected(VCC *vcc);
