@@ -37,7 +37,7 @@
 
 #include "g_types.h"    /* General Purpose Types      */
 #include "codes.h"      /* Return Status Codes        */
-#include "atm.h"        /* ATM Specific Definitions   */
+#include "lane_atm.h"   /* ATM Specific Definitions   */
 #include "utl.h"        /* General Purpose Utilities  */
 #include "utl_os.h"     /* Operating System Utilities */
 #include "system.h"
@@ -79,6 +79,10 @@ typedef struct {
 
 static LA_CONTEXT lec_arp_context;
 
+/*
+ * LE_ARP request from kernel
+ * LANE2: LE_ARP frames can now contain variable size TLVs
+ */
 static void
 kernel_arp_xmt_callback(struct atmlec_msg *mesg)
 {
@@ -88,7 +92,8 @@ kernel_arp_xmt_callback(struct atmlec_msg *mesg)
   to_pass = (ESI*)mesg->content.normal.mac_addr;
 
   utl_list_traverse(lec_arp_context.elan_list, p_elan) {
-    lec_arp_context.arp_xmt_callback(p_elan->lc_elan_handle, *to_pass);
+    lec_arp_context.arp_xmt_callback(p_elan->lc_elan_handle,
+                                     *to_pass, mesg->sizeoftlvs);
   }
 }
 
@@ -102,7 +107,7 @@ kernel_flush_xmt(unsigned char *to_pass)
     lec_arp_context.flush_xmt_callback(p_elan->lc_elan_handle, to_pass,&dumb);
     EVENT(EM_DEBUG,("Setting flush transaction id to %lx\n",dumb));
     kernel_sendmsg(l_flush_tran_id, NULL, to_pass,
-		   NULL, dumb);
+		   NULL, dumb, NULL, 0);
   }
 }
 
@@ -222,7 +227,7 @@ la_config(HANDLE la_elan_handle, LAN_TYPE lan_type,
   conf_mesg.arp_response_time = le_arp_response_time;
   conf_mesg.flush_timeout = flush_timeout;
   conf_mesg.path_switching_delay = path_switching_delay;
-  kernel_sendmsg(l_config, NULL, NULL, &conf_mesg, 0);
+  kernel_sendmsg(l_config, NULL, NULL, &conf_mesg, 0, NULL, 0);
 }
 
 STATUS 
@@ -231,20 +236,27 @@ la_addr_delete(HANDLE la_elan_handle,
 	       BOOLEAN permanent)
 {
   kernel_sendmsg(l_addr_delete, NULL, atm_addr, NULL,
-		  permanent==TRUE?1:0);
+		  permanent==TRUE?1:0, NULL, 0);
   return STATUS_K_SUCCESS;
 }
 
+/*
+ * LANE2: tlv_list passing added
+ *
+ */
 void 
 la_arp_update(HANDLE    la_elan_handle,
 	      ESI       esi,
 	      ADDR_ATM  addr_atm,
-	      BOOLEAN   remote_flag)
+	      BOOLEAN   remote_flag,
+              char      *tlv_list,
+              int       sizeoftlvs)
 {
   EVENT(EM_DEBUG,("ARP update for %2.2x%2.2x%2.2x%2.2x%2.2x%2.2x\n",
 		  esi[0],esi[1],esi[2],esi[3],esi[4],esi[5]));
   kernel_sendmsg(l_arp_update, (unsigned char *)esi,
-		 (unsigned char *)&addr_atm, NULL, remote_flag==TRUE?1:0);
+		 (unsigned char *)&addr_atm, NULL, remote_flag==TRUE?1:0,
+                 tlv_list, sizeoftlvs);
 }
 
 void 
@@ -253,7 +265,7 @@ la_flush_complete(HANDLE la_elan_handle,
 {
   EVENT(EM_DEBUG,("Flush complete for tran_id %lx\n", tran_id));
   kernel_sendmsg(l_flush_complete, NULL,
-		 NULL, NULL, tran_id);
+		 NULL, NULL, tran_id, NULL, 0);
 }
 
 void 
@@ -261,7 +273,8 @@ la_topology_change_set(HANDLE  la_elan_handle,
 		       BOOLEAN topology_change_flag)
 {
   kernel_sendmsg(l_topology_change, NULL, NULL, NULL,
-		 topology_change_flag==TRUE?1:0);
+		 topology_change_flag==TRUE?1:0,
+                 NULL, 0);
 }
 
 
