@@ -1,10 +1,11 @@
 /* arequipa.h - AREQUIPA support functions */
  
-/* Written 1996,1997 by Jean-Michel Pittet and Werner Almesberger, EPFL-LRC */
+/* Written 1996-1998 by Jean-Michel Pittet and Werner Almesberger,
+			EPFL-LRC/ICA */
  
 
-#ifndef AREQUIPA_H
-#define AREQUIPA_H
+#ifndef _AREQUIPA_H
+#define _AREQUIPA_H
 
 #include <linux/atm.h>
 
