@@ -1,12 +1,11 @@
 /* atm2text.c - Converts binary encoding of ATM address to textual
 		representation */
 
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdio.h>
 #include <string.h>
-#include <linux/atm.h>
 
 #include "atm.h"
 #include "atmres.h"
