@@ -80,16 +80,15 @@ int main(int argc,const char *const *argv)
     else {
 	struct atm_iobuf req;
 	int buf[BUF_LEN];
-	int size,i;
+	int i;
 
 	req.length = BUF_LEN*sizeof(int);
 	req.buffer = buf;
-	size = ioctl(s,ATM_GETNAMES,&req);
-	if (size < 0) {
+	if (ioctl(s,ATM_GETNAMES,&req) < 0) {
 	    perror("ioctl ATM_GETNAMES");
 	    return 1;
 	}
-	for (i = 0; i < size; i++) display(s,buf[i],zero);
+	for (i = 0; i < req.length/sizeof(int); i++) display(s,buf[i],zero);
     }
     return 0;
 }
