@@ -1,6 +1,6 @@
 /* proto.c - Common protocol functions and structures */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdarg.h>
@@ -26,6 +26,7 @@ const char *state_name[] = { /* formatting aligned with STATE */
 	"<invalid>",	"ss_null",	"ss_listening",	"ss_connecting",
 	"ss_connected",	"ss_indicated",	"ss_accepting",	"ss_zombie",
 	"ss_wait_rel",	"ss_wait_close","ss_rel_req",	"ss_rel_ind",
+	"ss_proceeding","ss_listen_zombie",
 	"ss_mod_lcl",	"ss_mod_req",	"ss_mod_rcv",	"ss_mod_fin_ack",
 	"ss_mod_fin_ok","ss_mod_fin_fail"
 	};
@@ -38,12 +39,13 @@ const char *cs_name[] = {
 
 const char *as_name[] = { "<invalid>","as_bind","as_connect","as_accept",
   "as_reject","as_listen","as_okay","as_error","as_indicate","as_close",
-  "as_itf_notify","as_modify" };
+  "as_itf_notify","as_modify","as_identify" };
 
 const CALL_STATE state_map[] = { /* formatting aligned with STATE */
 	cs_null,	cs_null,	cs_null,	cs_call_init,
 	cs_active,	cs_in_proc,	cs_conn_req,	cs_null,
 	cs_rel_req,	cs_null,	cs_rel_req,	cs_rel_ind,
+	cs_in_proc,	cs_null,
 #ifdef Q2963_1
 	cs_active,	cs_mod_req,	cs_mod_rcv,	cs_active,
 	cs_active,	cs_active
@@ -286,7 +288,7 @@ void set_error(SOCKET *sock,int code)
 
 void send_close(SOCKET *sock)
 {
-    if (sock->error == 1234) diag(COMPONENT,DIAG_ERROR,"BUG! BUG! BUG!");
+    if (sock->error == 1234) diag(COMPONENT,DIAG_FATAL,"BUG! BUG! BUG!");
     send_kernel(sock->id,0L,as_close,sock->error,NULL,NULL,NULL,NULL,NULL);
     sock->error = 1234;
 }
