@@ -1,12 +1,11 @@
 /* timeout.c - Processing of signaling timeout events */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdio.h>
 #include <errno.h>
 #include <assert.h>
-#include <linux/atmdev.h>
 
 #include "atmd.h"
 
