@@ -1,6 +1,6 @@
 /* trace.c - Support functions for message tracing */
  
-/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1996-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -138,18 +138,10 @@ static void append_qos(const struct atm_qos *qos)
 
 static void qd_vdump(const char *msg,va_list ap)
 {
-    const char *prev,*end;
-
     if (new_line) append("  ");
-    prev = string;
     vappend(msg,ap);
-    if (!prev) prev = string;
-    if (!prev) new_line = 1;
-    else {
-	if (!(end = strrchr(prev,'\n'))) end = prev;
-	else end++;
-	new_line = !*end;
-    }
+    if (string && curr_len) new_line = string[curr_len-1] == '\n';
+    else new_line = 1;
 }
 
 
@@ -188,7 +180,7 @@ static void print_kernel(void *msg,int size)
 {
     static const char *type[] = { "as_catch_null","as_bind","as_connect",
       "as_accept","as_reject","as_listen","as_okay","as_error","as_indicate",
-      "as_close","as_itf_notify" };
+      "as_close","as_itf_notify","as_modify","as_identify" };
     struct atmsvc_msg *m = msg;
 
     append("  %s (vcc 0x%x, listen_vcc 0x%x)\n",m->type < sizeof(type)/
@@ -283,11 +275,11 @@ char *get_trace(void)
     if (string) {
 	free(string);
 	string = NULL;
-	new_line = 1;
     }
     for (walk = first; walk; walk = walk->next) {
 	append("%6d (%d.%06d) %s:\n",walk->number,walk->time.tv_sec,
 	  walk->time.tv_usec,walk->comment);
+	new_line = 1;
 	walk->print(walk->msg,walk->size);
     }
     return string;
